.. cdsaxs documentation master file, created by
   sphinx-quickstart on Tue Jul 30 15:43:11 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

cdsaxs documentation
====================

.. toctree::
   :maxdepth: 3
   :caption: User Guide:

   introduction
   tutorials
   modules

.. toctree::
   :maxdepth: 2
   :caption: For Developers:

   for_developpers

Indices and tables
==================


